The contents of this folder are generated by running the generate_data.py script for:

git@github.com:CampusAI/Hamiltonian-Generative-Networks.git

commit 702d3ff (July 31, 2021)

The parameters used for the runs are available in parameters.yaml file(s). A very small and unrealistic number of train/test runs are included in this folder for functional testing purposes.
